Structs
- Client
- A
Clientto make Requests with. - WebAvailability
- The
WebAvailabilitystruct represents a monitor that checks the availability of a web service.
Client to make Requests with.WebAvailability struct represents a monitor that checks the availability of
a web service.